# -------------------------------------------------------------------------------------------------
# This script is to duplicate the seasonal verification done for Focus-Africa WP4.
# 
# Forecasting system: ECMWF SEAS5
# Lead times: 0-5 months
# Observation: ERA5
# Variables: prlr, tas
# Frequency: monthly (aggregated to 3-month seasonal sum/mean)
# Regrid: Both forecast and observation are interpolated to JMA-2 grid.
# Period: 1981-2016
# Calibration methods: RAW, bias, evmos and mse_min
# Skill metrics: corr, bss10, bss90, frpss
# Spatial domain: 0-60ºN, 40ºS-10ºN (the SADC region)
#
# Chung, June 2022
# -------------------------------------------------------------------------------------------------

# Output plots directory
output.dir <- '/esarchive/scratch/cchou/FOCUS/seasonal-verification/output/auto-s2s/plots/'
# Replace with the path to the recipe you want to use
recipe_file <- "modules/Loading/testing_recipes/c_recipe.yml"

source("modules/Loading/Loading.R")
source("modules/Calibration/Calibration.R")
source("modules/Skill/Skill.R")

# Load datasets
data <- load_datasets(recipe_file)

recipe <- read_yaml(recipe_file)
# Calibrate datasets
calibrated_data <- calibrate_datasets(data, recipe)
# Compute skill metrics
skill_metrics <- compute_skill_metrics(calibrated_data$hcst, data$obs,
                                       recipe, na.rm = T, ncores = 1)

# Taking a look at one of the arrays in the metric list...
dim(skill_metrics$enscorr$enscorr_specs)
#     dat       var      sday     sweek      time  latitude longitude 
#       1         1         1         1         2        20        20 

corr_new <- skill_metrics$enscorr$enscorr_specs[, , , , 1, ,]

# Load the outputs from previous workflow
library(ncdf4)

system <- 'ecmwfs5'; calib_mode <- 'bias'; time_agg <- 'monthly'; var <- 'tas'; date <- '20210101'
userdirectory <- '/esarchive/scratch/cchou/FOCUS/seasonal-verification/output/JMAGrid/'
fname <- paste0(system, '/', calib_mode, '-', time_agg, '/', var, '/', date, '/')
nc_data <- nc_open(paste0(userdirectory, fname, var, '-skill_month', substr(date, 5, 6), '.nc'))
get_var <- 'corr_r'
skill <- ncvar_get(nc_data, get_var)
names(dim(skill)) <- c('lon', 'lat', 'leadtime')
corr_old <- skill[,,1]




# Plot examples
fname <- paste0(var, '_', substr(date, 5, 6), '_', get_var, '_auto-s2s.png')
PlotEquiMap(corr_new,
            data$hcst$lon[1:length(data$hcst$lon)],
            data$hcst$lat[1:length(data$hcst$lat)],
            toptitle = "Correlation (auto-s2s)",
filled.continents = FALSE, filled.oceans = "lightgrey", country.borders = TRUE,
brks = seq(-1, 1, 0.1), width = 5, height = 6,
triangle_ends_scale = 1, triangle_ends = c(FALSE,FALSE),
fileout = paste0(output.dir, fname))

fname <- paste0(var, '_', substr(date, 5, 6), '_', get_var, '_s2s4e.png')
PlotEquiMap(corr_old,
            data$hcst$lon[1:length(data$hcst$lon)],
            rev(data$hcst$lat[1:length(data$hcst$lat)]),
            toptitle = "Correlation (s2s4e)",
filled.continents = FALSE, filled.oceans = "lightgrey", country.borders = TRUE,
brks = seq(-1, 1, 0.1), width = 5, height = 6,
triangle_ends_scale = 1, triangle_ends = c(FALSE,FALSE),
fileout = paste0(output.dir, fname))



# -------------------------------------------------------------------------------------------------
# The script below takes advantage of the above data to test CSDownscale's interpolation function.
# 
# Chung, June 2022
# -------------------------------------------------------------------------------------------------


